/*
 * @file: HttpPost.java
 *
 */

package edu.mit.ll.tools.http;

import org.apache.commons.httpclient.*;
import org.apache.commons.httpclient.auth.AuthScope;
import org.apache.commons.httpclient.methods.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 *  HTTP reader utility class to copy files from an HTTP server to a local file.
 *  Supports username/password credentials
 *
 */
public class HttpPost
{
  private static final Log log = 
    LogFactory.getLog( HttpPost.class.getName() );

  public static void usage() {
    
    System.out.println("Usage: java -classpath <classpath> HttpPost <url> <filename>]");
    System.out.println("<classpath> - must contain the commons-httpclient.jar and commons-logging.jar");
    System.out.println("<url> - the URL to post the file to");
    System.out.println("<filename> - file to post to the URL");
    System.out.println();
    System.exit(1);
  }
  
  public static void main(String[] args) throws Exception {
    if (args.length != 2) {
      usage();
    }

    // Get target URL
    String url = args[0];

    // Get file to be posted
    String filename = args[1];
    File input = new File( filename );

    PostMethod post = new PostMethod( url );

    RequestEntity entity = new FileRequestEntity(input, "text/xml; charset=ISO-8859-1");
    post.setRequestEntity(entity);

    HttpClient httpclient = new HttpClient();

    // Execute request
    try {
      int result = httpclient.executeMethod(post);

      // Display status code
      System.out.println("Response status code: " + result);

      // Display response
      System.out.println("Response body: ");
      System.out.println( post.getResponseBodyAsString() );

    } finally {

      // Release current connection to the connection pool once you are done
      post.releaseConnection();
    }
  }

  /*
  private static int DEFAULT_CONNECTION_TIMEOUT_MS = 10000;
  HttpClient _client;
  int        _connectionTimeout_ms = DEFAULT_CONNECTION_TIMEOUT_MS;

  public HttpPost()
  {
    init( null, null );
  }

  public HttpPost( String userName, String password )
  {
    init( userName, password );
  }

  public void init( String userName, String password )
  {
    // Create a singular HttpClient object
    _client = new HttpClient();

    // Establish a connection within 5 seconds
    _client.getHttpConnectionManager().getParams().
                                       setConnectionTimeout( _connectionTimeout_ms );

    // If proxy was set on Java command-line, pass it to the HTTP client
    // instance (this gets done automatically for the built-in Java
    // HTTP connection code)
    String proxyHost = System.getProperty("http.proxyHost");
    String proxyPortStr = System.getProperty("http.proxyPort");
    int proxyPort = 80;

    if( proxyHost != null )
    {
      if( proxyPortStr != null )
        proxyPort = Integer.parseInt(proxyPortStr);
      
      _client.getHostConfiguration().setProxy( proxyHost, proxyPort );
    }
    
    // Set the default credentials
    if( (userName != null) && (password != null) ) {
      Credentials creds = new UsernamePasswordCredentials( userName, password );
      _client.getState().setCredentials( AuthScope.ANY, creds );
    }
  }
  
  public void setConnectionTimeout( int timeout_ms )
  {
    _connectionTimeout_ms = timeout_ms;
  }
  */  

}
